/*
	client.h

	Client definitions

	Copyright (C) 1996-1997  Id Software, Inc.

	This program is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 2
	of the License, or (at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

	See the GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to:

		Free Software Foundation, Inc.
		59 Temple Place - Suite 330
		Boston, MA  02111-1307, USA

*/

#ifndef _CL_DEMO_H
#define _CL_DEMO_H

#include "QF/qtypes.h"
#include "qw/protocol.h"

void CL_StopPlayback (void);
int CL_GetMessage (void);
void CL_WriteDemoCmd (usercmd_t *pcmd);

void CL_StopRecording (void);
void CL_Record (const char *argv1, int track);	// track ignored

void CL_Demo_Init (void);

extern struct cvar_s *demo_speed;
extern struct cvar_s *demo_gzip;

#endif
